from __future__ import unicode_literals

from reviewboard.extensions.base import Extension, JSExtension
from reviewboard.extensions.hooks import TemplateHook
from reviewboard.urls import reviewable_url_names, review_request_url_names


_apply_to_url_names = set(reviewable_url_names + review_request_url_names)


class StopwatchJSExtension(JSExtension):
    """Javascript extension for the stopwatch."""

    model_class = 'RBStopwatch.Extension'
    apply_to = _apply_to_url_names


class StopwatchExtension(Extension):
    """A stopwatch extension.

    This extension adds a bit of UI to every review request page that gives
    reviewers a "stopwatch" which allows them to turn on and off a timer. The
    total time spent reviewing will be added to the Review's extra_data.
    """

    metadata = {
        'Name': 'Review Stopwatch',
        'Summary': 'A stopwatch for reviewers: keep track of the total time '
                   'spent on each code review.',
    }

    js_extensions = [StopwatchJSExtension]

    css_bundles = {
        'default': {
            'source_filenames': ['css/stopwatch.less'],
            'apply_to': _apply_to_url_names,
        },
    }

    js_bundles = {
        'default': {
            'source_filenames': ['js/stopwatch.js'],
            'apply_to': _apply_to_url_names,
        },
    }

    def initialize(self):
        """Initialize the extension."""
        TemplateHook(self, 'review-summary-header-post',
                     'rbstopwatch-review-header.html',
                     apply_to=['review-request-detail'])



from __future__ import division, unicode_literals

from django import template
from django.utils.html import format_html
from django.utils.translation import ugettext as _


register = template.Library()


@register.filter
def review_time(review):
    if review.extra_data and 'rbstopwatch.reviewTime' in review.extra_data:
        totalSeconds = int(review.extra_data['rbstopwatch.reviewTime'])

        hours = totalSeconds // 3600
        minutes = (totalSeconds % 3600) // 60
        seconds = (totalSeconds % 60)

        time = '%02d:%02d:%02d' % (hours, minutes, seconds)

        return format_html(
            '<div class="rbstopwatch-review-header">{0}</div>',
            _('Total time spent on this review: %s') % time)

    return ''



from __future__ import unicode_literals


# The version of rbstopwatch
#
# This is in the format of:
#
#   (Major, Minor, Micro, Patch, alpha/beta/rc/final, Release Number, Released)
#
VERSION = (1, 0, 1, 0, 'final', 0, True)


def get_version_string():
    version = '%s.%s' % (VERSION[0], VERSION[1])

    if VERSION[2] or VERSION[3]:
        version += ".%s" % VERSION[2]

    if VERSION[3]:
        version += ".%s" % VERSION[3]

    if VERSION[4] != 'final':
        if VERSION[4] == 'rc':
            version += ' RC%s' % VERSION[5]
        else:
            version += ' %s %s' % (VERSION[4], VERSION[5])

    if not is_release():
        version += " (dev)"

    return version


def get_package_version():
    version = '%s.%s' % (VERSION[0], VERSION[1])

    if VERSION[2] or VERSION[3]:
        version += ".%s" % VERSION[2]

    if VERSION[3]:
        version += ".%s" % VERSION[3]

    if VERSION[4] != 'final':
        version += '%s%s' % (VERSION[4], VERSION[5])

    return version


def is_release():
    return VERSION[6]


__version_info__ = VERSION[:-1]
__version__ = get_package_version()



from __future__ import unicode_literals

from setuptools import find_packages
from reviewboard.extensions.packaging import setup

from rbstopwatch import get_package_version


setup(
    name='rbstopwatch',
    version=get_package_version(),
    description='Stopwatch extension for Review Board',
    url='https://www.reviewboard.org/',
    author='Beanbag, Inc.',
    author_email='support@beanbaginc.com',
    maintainer='Beanbag, Inc.',
    maintainer_email='support@beanbaginc.com',
    packages=find_packages(),
    entry_points={
        'reviewboard.extensions': [
            'rbstopwatch = rbstopwatch.extension:StopwatchExtension',
        ],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Review Board',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ]
)
